@@ -5,16 +5,15 @@ from sql.conditionals import Case
 
 from trytond.model import fields
 from trytond.pyson import Not, Eval, Bool
-from trytond.transaction import Transaction
 from trytond import backend
 from trytond.pool import PoolMeta
 
 __all__ = ['Location']
-__metaclass__ = PoolMeta
 
 
 class Location:
     "Stock Location"
+    __metaclass__ = PoolMeta
     __name__ = 'stock.location'
     sequence = fields.Integer('Sequence',
         states={
@@ -30,8 +29,7 @@ class Location:
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         super(Location, cls).__register__(module_name)
 
